==> openjdk-11_11.0.29~4ea.orig.tar.xz: openjdk-11-11.0.29~4ea/test/jdk/java/beans/XMLEncoder/javax_swing_plaf_BorderUIResource_MatteBorderUIResource.java <==
/*
 * Copyright (c) 2006, 2007, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 6402062
 * @summary Tests MatteBorderUIResource encoding
 * @author Sergey Malenkov
 */

import java.awt.Color;
import javax.swing.plaf.BorderUIResource.MatteBorderUIResource;

public final class javax_swing_plaf_BorderUIResource_MatteBorderUIResource extends AbstractTest<MatteBorderUIResource> {
    public static void main(String[] args) {
        new javax_swing_plaf_BorderUIResource_MatteBorderUIResource().test(true);
    }

    protected MatteBorderUIResource getObject() {
        return new MatteBorderUIResource(1, 2, 3, 4, Color.RED);
    }

    protected MatteBorderUIResource getAnotherObject() {
        return null; // TODO: could not update property
        // return new MatteBorderUIResource(null);
    }
}

==> openjdk-26_26~34ea.orig.tar.xz: openjdk-26-26~34ea/test/jdk/java/beans/XMLEncoder/javax_swing_plaf_BorderUIResource_MatteBorderUIResource.java <==
/*
 * Copyright (c) 2006, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/*
 * @test
 * @bug 6402062
 * @summary Tests MatteBorderUIResource encoding
 * @run main/othervm javax_swing_plaf_BorderUIResource_MatteBorderUIResource
 * @author Sergey Malenkov
 */

import java.awt.Color;
import javax.swing.plaf.BorderUIResource.MatteBorderUIResource;

public final class javax_swing_plaf_BorderUIResource_MatteBorderUIResource extends AbstractTest<MatteBorderUIResource> {
    public static void main(String[] args) {
        new javax_swing_plaf_BorderUIResource_MatteBorderUIResource().test();
    }

    protected MatteBorderUIResource getObject() {
        return new MatteBorderUIResource(1, 2, 3, 4, Color.RED);
    }

    protected MatteBorderUIResource getAnotherObject() {
        return null; // TODO: could not update property
        // return new MatteBorderUIResource(null);
    }
}
